@@ -1,5 +1,6 @@
 package Text::Tokenizer;
 
+use 5.008001;
 use strict;
 use warnings;
 use Carp;
@@ -17,16 +18,13 @@ our @ISA = qw(Exporter);
 # If you do not need this, moving things directly into @EXPORT or @EXPORT_OK
 # will save memory.
 our %EXPORT_TAGS = ( 'all' => [ qw(
+	
 	TOK_UNDEF TOK_TEXT TOK_DQUOTE TOK_SQUOTE TOK_IQUOTE
 	TOK_SIQUOTE TOK_BLANK TOK_ERROR TOK_EOL TOK_COMMENT TOK_EOF
-	TOK_BASH_COMMENT TOK_C_COMMENT TOK_CC_COMMENT
 	NOERR UNCLOSED_DQUOTE UNCLOSED_SQUOTE UNCLOSED_IQUOTE NOCONTEXT
-	UNCLOSED_C_COMMENT
 	TOK_OPT_DEFAULT TOK_OPT_NONE TOK_OPT_NOUNESCAPE
 	TOK_OPT_SIQUOTE TOK_OPT_UNESCAPE TOK_OPT_UNESCAPE_CHARS
-	TOK_OPT_UNESCAPE_LINES TOK_OPT_PASSCOMMENT TOK_OPT_PASS_COMMENT
-	TOK_OPT_UNESCAPE_NQ_LINES TOK_OPT_C_COMMENT TOK_OPT_CC_COMMENT
-	TOK_OPT_NO_BASH_COMMENT TOK_OPT_NO_IQUOTE
+	TOK_OPT_UNESCAPE_LINES TOK_OPT_PASSCOMMENT
 	tokenizer_options
 	tokenizer_new
 	tokenizer_new_strbuf
@@ -44,14 +42,10 @@ our @EXPORT = qw(
 	
 	TOK_UNDEF TOK_TEXT TOK_DQUOTE TOK_SQUOTE TOK_IQUOTE
 	TOK_SIQUOTE TOK_BLANK TOK_ERROR TOK_EOL TOK_COMMENT TOK_EOF
-	TOK_BASH_COMMENT TOK_C_COMMENT TOK_CC_COMMENT
 	NOERR UNCLOSED_DQUOTE UNCLOSED_SQUOTE UNCLOSED_IQUOTE NOCONTEXT
-	UNCLOSED_C_COMMENT
 	TOK_OPT_DEFAULT TOK_OPT_NONE TOK_OPT_NOUNESCAPE
 	TOK_OPT_SIQUOTE TOK_OPT_UNESCAPE TOK_OPT_UNESCAPE_CHARS
-	TOK_OPT_UNESCAPE_LINES TOK_OPT_PASSCOMMENT TOK_OPT_PASS_COMMENT
-	TOK_OPT_UNESCAPE_NQ_LINES TOK_OPT_C_COMMENT TOK_OPT_CC_COMMENT
-	TOK_OPT_NO_BASH_COMMENT TOK_OPT_NO_IQUOTE
+	TOK_OPT_UNESCAPE_LINES TOK_OPT_PASSCOMMENT
 	tokenizer_options
 	tokenizer_new
 	tokenizer_new_strbuf
@@ -60,10 +54,10 @@ our @EXPORT = qw(
 	tokenizer_switch
 	tokenizer_delete
 	tokenizer_flush
-	tokenizer_destroy	
+	tokenizer_destroy
 );
 
-our $VERSION = '0.4.6';
+our $VERSION = '0.2';
 
 sub AUTOLOAD {
     # This AUTOLOAD is used to 'autoload' constants from the constant()
@@ -108,34 +102,31 @@ Text::Tokenizer - Perl extension for tokenizing text(config) files
   use Text::Tokenizer ':all';
 
   #open file and set add it to tokenizer inputs
-  open(F_CONFIG, "input.conf") || die("failed to open input.conf");
+  open(F_CONFIG, "input.conf");	
   $tok_id	= tokenizer_new(F_CONFIG);
   tokenizer_options(TOK_OPT_NOUNESCAPE|TOK_OPT_PASSCOMMENT);
 
   while(1)
   {
 	($string, $tok_type, $line, $err, $errline)	= tokenizer_scan();
-	last if($tok_type == TOK_ERROR || $tok_type == TOK_EOF);
+	last if($tok == TOK_ERROR || $tok == TOK_EOF);
 
-	if($tok_type == TOK_TEXT)	{ 	}
-	elsif($tok_type == TOK_BLANK)	{ 	}
-	elsif($tok_type == TOK_DQUOTE)	{ $string	= "\"$str\"";	}
-	elsif($tok_type == TOK_SQUOTE)	{ $string	= "\'$str\'";	}
-	elsif($tok_type == TOK_SIQUOTE)	{ $string	= "\`$str\'";	}
-	elsif($tok_type == TOK_IQUOTE)	{ $string	= "\`$str\`";	}
-	elsif($tok_type == TOK_EOL)	{ $string	= "\n";		}
-	elsif($tok_type == TOK_COMMENT)	{	}
-	elsif($tok_type == TOK_UNDEF)
-		{ last;	}
+	if($tok == TOK_TEXT)		{ 	}
+	elsif($tok == TOK_BLANK)	{ 	}
+	elsif($tok == TOK_DQUOTE)	{ $str	= "\"$str\"";	}
+	elsif($tok == TOK_SQUOTE)	{ $str	= "\'$str\'";	}
+	elsif($tok == TOK_SIQUOTE)	{ $str	= "\`$str\'";	}
+	elsif($tok == TOK_IQUOTE)	{ $str	= "\`$str\`";	}
+	elsif($tok == TOK_EOL)		{	}
+	elsif($tok == TOK_COMMENT)	{	}
+	elsif($tok == TOK_UNDEF)
+		{ last;		}
 	else	{ last;	};
-	print $string;
+	print $str;
   }
-  tokenizer_delete($tok_id);
+  tokenizer_delete($tokid);
 
 
-  Very complex example of using Text::Tokenizer can be found in passwd_exp - tool for password
-  expiration notification (http://devel.dob.sk/passwd_exp)
-
 =head1 DESCRIPTION
 
 B<Text::Tokenizer> is I<very fast> lexical analyzer, that can be used to process input text
@@ -172,12 +163,8 @@ to import all constants & methods.
 
 =over 17
 
-=back
-
 =head2 I<TOKEN TYPES> Token types that tokenizer returns.
 
-=over
-
 =item	B<TOK_UNDEF>
 
 Undefined token (tokenizer error)
@@ -222,12 +209,9 @@ End of File
 
 Error Condition (see C<ERROR_TYPES>)
 
-=back
 
 =head2 I<ERROR TYPES> Error codes that will tokenizer return if error happens.
 
-=over
-
 =item	B<NOERR>
 
 No error
@@ -248,12 +232,9 @@ Unclosed inverse quote found
 
 Failed to allocate tokenizer context (FATAL ERROR)
 
-=back
 
 =head2 I<TOKENIZER OPTIONS> Options configurable for tokenizer. They should be OR-ed when passing to tokenizer_options.
 
-=over
-
 =item	B<TOK_OPT_DEFAULT>
 
 Default options set, equals to TOK_OPT_NOUNESCAPE
@@ -262,7 +243,7 @@ Default options set, equals to TOK_OPT_NOUNESCAPE
 
 Set no options. Tokenizer will do in it's default behaviour - it will not unescape anything
 and it will not pass comments to you.
-
+	
 =item	B<TOK_OPT_NOUNESCAPE>
 
 Disable characters & lines unescaping.
@@ -277,20 +258,16 @@ Unescape chars & lines.
 
 =item	B<TOK_OPT_UNESCAPE_CHARS>
 
-Unescape chars (inside of quotes only)
+Unescape chars
 
 =item	B<TOK_OPT_UNESCAPE_LINES>
 
-Unescape lines (inside of quotes only)
+Unescape lines
 
 =item	B<TOK_OPT_PASSCOMMENT>
 
 Enable comment passing to user routines.
 
-=item	B<TOK_OPT_UNESCAPE_NQ_LINES>
-
-Unescape lines (outside of quotes). Escaped end of line will not terminate value processing processing.
-So escaped multiline text will be returned as single line string.
 
 =back
 
@@ -319,6 +296,7 @@ Scan current tokenizer instance, and return first token found.
 	@tok	= ($string, $type, $line, $error, $error_line)
 
 =over 10
+=over 10
 
 =item	$string		- found token string
 
@@ -331,23 +309,24 @@ Scan current tokenizer instance, and return first token found.
 =item	$error_line	- line number where error begins (unclosed quote position)
 
 =back
-
+=back
+	
 =item	B<tokenizer_exists(TOK_ID)>
 
 Test if tokenizer instance exists.
 
 =item	B<tokenizer_switch(TOK_ID)>
 
-Switch to another tokenizer instance (like when you perform include statement).
+Switch to another tokenizer instance (like when you perform include statment).
 
 =item	B<tokenizer_delete(TOK_ID)>
 
-Delete tokenizer instance You have to do it exactly on EOF to release tokenizer
-reference to file or buffer.
+Delete tokenizer instance (You have to do it exactly on EOF to release connection
+between file or buffer.
 
 =item	B<tokenizer_flush(TOK_ID)>
 
-Flush tokenizer instance. This  function  discards  the  instance buffer\s  contents, so the 
+Flush tokenizer instance. This  function  discards  the  instance buffer's  contents, so the 
 next time the scanner attempts to match a token from the buffer, it will have to fill it.
 
 =back
@@ -359,13 +338,13 @@ This tokenizer is based on code generated by B<flex> - fast lexical analyzer gen
 
 =head1 AUTHOR
 
-Samuel Behan, (http://devel.dob.sk)
+Samuel Behan, E<lt>sam@frida.fri.utc.skE<gt>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2003-2011 by Samuel Behan
+Copyright 2003-2004 by Samuel Behan
 
 This library is free software; you can redistribute it and/or modify
-it under the terms of GNU/GPL v3.
+it under the same terms of GNU/GPL v2. 
 
 =cut
